@@ -2,40 +2,22 @@
 # - Package Imports -
 # ----------------------------------------------------------------------------------------------------------------------
 # General Packages
+from __future__ import annotations
 
 # Custom Library
 
 # Custom Packages
-from AthenaColor.Help.readme import readme
+import AthenaColor
+
+# ----------------------------------------------------------------------------------------------------------------------
+# - All -
+# ----------------------------------------------------------------------------------------------------------------------
 
 # ----------------------------------------------------------------------------------------------------------------------
 # - Code -
 # ----------------------------------------------------------------------------------------------------------------------
-if __name__ == "__main__":
-    readme()
+def main():
+    pass
 
-
-    from AthenaColor.Styling.Callable import (
-        Fore, Back, Style
-    )
-
-    print(
-        Fore.Blue(
-            "blue",
-            Fore.Red("red"),
-            Back.Crimson("something"),
-            Style.Bold("PLEASE HELP ME"),
-            Style.Underline("HERE"),
-            "blue",
-            Fore.Red("red"),
-        )
-    )
-
-    print(
-        Style.Bold(
-            "BOLD",
-            Style.Bold("BOLD"),
-            "BOLD"
-        ),
-        "not"
-    )
+if __name__ == '__main__':
+    main()
\ No newline at end of file
